# Contributors Thanks to the following individuals for providing pull requests, feedback, and other contributions that have helped to improve requests-cache: ---

Al Johri 🤔 | Alex Morega 📖 🐛 | Alex Sinitsin 💻 🐛 | Andrew Kittredge 📖 | Antonio Lima 💻 ✨ 🤔 | Boris Danilovich 💻 🐛 | Charles 🐛
Chris Wesseling 🤔 | Chris de Graaf 💻 ✨ | Daniel Rech 💻 📖 | David Stosik 🐛 | Dragon Dave McKee 💻 | Edward Betts 💻 📖 | Elan Ruusamäe 🐛 📖 🤔
Erik Körner 🐛 🤔 | FemtoTrader 💻 🐛 🤔 ✨ | Florian Demmer 💻 🐛 | GDR! 🐛 | Garrett Reynolds 💻 | Greg Dingle 🤔 | Guangnan Cheng 💻 ✨
Honza Javorek 🐛 🤔 | Ilya 💻 | J Rob Gant 💻 🐛 | Jace Browning 💻 📖 | Jakub Semrič 💻 🤔 | Jeremy Douglass 🤔 | Jessy Williams 💻 🐛 ⚠️
John Vandenberg 🚇 📦 ⚠️ | Jordan Cook 💻 🚧 ✨ 🐛 ⚠️ 📖 🚇 | Jürgen Hermann 🐛 🤔 | Kieran W 📖 🐛 | MHellmund 🐛 | Marc Abramowitz 💻 📖 | Marius Gedminas 💻 🐛
Masahiro Wada 💻 ✨ | Massimo Santini 🤔 | Michael Herman 💻 📖 | Michał Górny 🚇 | Michał Nowotka 🤔 | Mike 💻 ✨ | Nathan Cahill 🐛
Nick 🤔 | Olivier Dalang 💻 | Parker Hancock 💻 ✨ 🐛 ⚠️ 📖 🛡️ 🤔 | Philipp A. 🐛 | Roman Haritonov 💻 🚧 ✨ 🐛 ⚠️ 📖 🚇 | Samuel T. 🐛 🤔 | Sebastian Höffner 💻 ✨ ⚠️ 🤔
Simon Biewald 🛡️ 🤔 | Slin Lee 📖 | Stavros Korokithakis 🚇 🔧 📖 | Vladimir Panteleev 🤔 | Willem de Groot 💻 🐛 | Wouter Vanden Hove 🐛 | YetAnotherNerd 💻 ✨ 🐛
aaron-mf1 🤔 | coryairbhb 🐛 | craig 💻 🐛 | denis-bz 🐛 | gorogoroumaru 💻 | harvey251 🐛 | mbarkhau 💻 ⚠️ 🚇 🐛
shiftinv 💻 🐛 | witionstheme 🐛

--- This page was made using [all-contributors](https://github.com/all-contributors/all-contributors). See [emoji key](https://allcontributors.org/docs/en/emoji-key) for details on contribution types. If you notice a missing contributor or contribution type, please update it!